summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qlistviewitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qlistviewitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qlistviewitem_imp.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/kjsembed/qtbindings/qlistviewitem_imp.h b/kjsembed/qtbindings/qlistviewitem_imp.h
index 2f0eb21b..b4c7caa8 100644
--- a/kjsembed/qtbindings/qlistviewitem_imp.h
+++ b/kjsembed/qtbindings/qlistviewitem_imp.h
@@ -10,7 +10,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
#include <kjsembed/jsbindingbase.h>
-class TQListViewItem;
+class TTQListViewItem;
/**
* Namespace containing the KJSEmbed library.
@@ -18,7 +18,7 @@ class TQListViewItem;
namespace KJSEmbed {
namespace Bindings {
- class QListViewItemLoader : public JSBindingBase
+ class TQListViewItemLoader : public JSBindingBase
{
public:
KJS::Object createBinding(KJSEmbedPart *jspart, KJS::ExecState *exec, const KJS::List &args) const;
@@ -26,11 +26,11 @@ namespace Bindings {
};
}
/**
* Wrapper class for TQListViewItem methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QListViewItemImp : public JSProxyImp
+class TQListViewItemImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -107,8 +107,8 @@ public:
Method_Last = -1
};
- QListViewItemImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QListViewItemImp();
+ TQListViewItemImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQListViewItemImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -122,20 +122,20 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQListViewItem *toQListViewItem( KJS::Object &object );
+ static TTQListViewItem *toTQListViewItem( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QListViewItem_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_3( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_4( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_5( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_6( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_7( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QListViewItem_8( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_4( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_5( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_6( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_7( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQListViewItem_8( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -213,7 +213,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQListViewItem *instance; // Temp
+ TTQListViewItem *instance; // Temp
int id;
bool cons;
};
@@ -26,11 +26,11 @@ namespace Bindings {
}
/**
- * Wrapper class for TQListViewItem methods.
+ * Wrapper class for TTQListViewItem methods.
*
* @author Richard Moore, rich@kde.org